@@ -42,6 +42,7 @@ def includeme(config: Configurator) -> None:
     config.add_request_method(openapi_validated, name="openapi_validated", reify=True)
     config.add_view_deriver(openapi_view)
     config.add_directive("pyramid_openapi3_add_formatter", add_formatter)
+    config.add_directive("pyramid_openapi3_add_deserializer", add_deserializer)
     config.add_directive("pyramid_openapi3_add_explorer", add_explorer_view)
     config.add_directive("pyramid_openapi3_spec", add_spec_view)
     config.add_directive("pyramid_openapi3_spec_directory", add_spec_view_directory)
@@ -131,7 +132,7 @@ def add_explorer_view(
     route: str = "/docs/",
     route_name: str = "pyramid_openapi3.explorer",
     template: str = "static/index.html",
-    ui_version: str = "3.17.1",
+    ui_version: str = "4.10.3",
     permission: str = NO_PERMISSION_REQUIRED,
     apiname: str = "pyramid_openapi3",
 ) -> None:
@@ -177,6 +178,13 @@ def add_formatter(config: Configurator, name: str, func: t.Callable) -> None:
     reg[name] = func
 
 
+def add_deserializer(config: Configurator, name: str, func: t.Callable) -> None:
+    """Add support for configuring deserializers."""
+    config.registry.settings.setdefault("pyramid_openapi3_deserializers", {})
+    reg = config.registry.settings["pyramid_openapi3_deserializers"]
+    reg[name] = func
+
+
 def add_spec_view(
     config: Configurator,
     filepath: str,
@@ -215,16 +223,23 @@ def add_spec_view(
         config.add_view(route_name=route_name, permission=permission, view=spec_view)
 
         custom_formatters = config.registry.settings.get("pyramid_openapi3_formatters")
+        custom_deserializers = config.registry.settings.get(
+            "pyramid_openapi3_deserializers"
+        )
 
         config.registry.settings[apiname] = {
             "filepath": filepath,
             "spec_route_name": route_name,
             "spec": spec,
             "request_validator": RequestValidator(
-                spec, custom_formatters=custom_formatters
+                spec,
+                custom_formatters=custom_formatters,
+                custom_media_type_deserializers=custom_deserializers,
             ),
             "response_validator": ResponseValidator(
-                spec, custom_formatters=custom_formatters
+                spec,
+                custom_formatters=custom_formatters,
+                custom_media_type_deserializers=custom_deserializers,
             ),
         }
         config.registry.settings.setdefault("pyramid_openapi3_apinames", []).append(
@@ -239,6 +254,8 @@ def add_spec_view_directory(
     filepath: str,
     route: str = "/spec",
     route_name: str = "pyramid_openapi3.spec",
+    permission: str = NO_PERMISSION_REQUIRED,
+    apiname: str = "pyramid_openapi3",
 ) -> None:
     """Serve and register OpenApi 3.0 specification directory.
 
@@ -248,7 +265,7 @@ def add_spec_view_directory(
     """
 
     def register() -> None:
-        settings = config.registry.settings.get("pyramid_openapi3")
+        settings = config.registry.settings.get(apiname)
         if settings and settings.get("spec") is not None:
             raise ConfigurationError(
                 "Spec has already been configured. You may only call "
@@ -268,24 +285,34 @@ def add_spec_view_directory(
         validate_spec(spec_dict, spec_url=spec_url)
         spec = create_spec(spec_dict, spec_url=spec_url)
 
-        config.add_static_view(route, str(path.parent))
+        config.add_static_view(route, str(path.parent), permission=permission)
         config.add_route(route_name, f"{route}/{path.name}")
 
         custom_formatters = config.registry.settings.get("pyramid_openapi3_formatters")
+        custom_deserializers = config.registry.settings.get(
+            "pyramid_openapi3_deserializers"
+        )
 
-        config.registry.settings["pyramid_openapi3"] = {
+        config.registry.settings[apiname] = {
             "filepath": filepath,
             "spec_route_name": route_name,
             "spec": spec,
             "request_validator": RequestValidator(
-                spec, custom_formatters=custom_formatters
+                spec,
+                custom_formatters=custom_formatters,
+                custom_media_type_deserializers=custom_deserializers,
             ),
             "response_validator": ResponseValidator(
-                spec, custom_formatters=custom_formatters
+                spec,
+                custom_formatters=custom_formatters,
+                custom_media_type_deserializers=custom_deserializers,
             ),
         }
+        config.registry.settings.setdefault("pyramid_openapi3_apinames", []).append(
+            apiname
+        )
 
-    config.action(("pyramid_openapi3_spec",), register, order=PHASE0_CONFIG)
+    config.action((f"{apiname}_spec",), register, order=PHASE0_CONFIG)
 
 
 def register_routes(
